@@ -146,7 +146,7 @@ class Filter(object):
 
         # optimal case for weekdays: remove Saturday and Sunday
         if (cal == 'WEEKDAY'):
-            return data_frame.ix[data_frame.index.dayofweek <= 4]
+            return data_frame[data_frame.index.dayofweek <= 4]
 
         # select only those holidays in the sample
         holidays_start = self.get_holidays(data_frame.index[0], data_frame.index[-1], cal, holidays_list = holidays_list)
@@ -179,7 +179,7 @@ class Filter(object):
         # indices = list(range(counter, len(floored_dates)))
         # indices_to_keep = indices_to_keep + indices
         #
-        # data_frame_filtered = data_frame.ix[indices_to_keep]
+        # data_frame_filtered = data_frame[indices_to_keep]
 
         if data_frame.index.tz is None:
             holidays_start = holidays_start.tz_localize(None)
@@ -191,8 +191,8 @@ class Filter(object):
         for i in range(0, len(holidays_start)):
 
 
-            data_frame_temp = data_frame_left.ix[data_frame_left.index < holidays_start[i]]
-            data_frame_left = data_frame_left.ix[data_frame_left.index >= holidays_end[i]]
+            data_frame_temp = data_frame_left[data_frame_left.index < holidays_start[i]]
+            data_frame_left = data_frame_left[data_frame_left.index >= holidays_end[i]]
 
             data_frame_filtered.append(data_frame_temp)
 
@@ -303,11 +303,19 @@ class Filter(object):
         if hasattr(data_frame.index, 'tz'):
             if data_frame.index.tz is not None:
 
+                # If the start/finish dates are timezone naive, overwrite with the DataFrame timezone
                 if not(isinstance(start_date, str)):
                     start_date = start_date.replace(tzinfo=data_frame.index.tz)
 
                 if not(isinstance(finish_date, str)):
                     finish_date = finish_date.replace(tzinfo=data_frame.index.tz)
+            else:
+                # Otherwise remove timezone from start_date/finish_date
+                if not (isinstance(start_date, str)):
+                    start_date = start_date.replace(tzinfo=None)
+
+                if not (isinstance(finish_date, str)):
+                    finish_date = finish_date.replace(tzinfo=None)
 
         if 'int' in str(data_frame.index.dtype):
             return data_frame
@@ -385,7 +393,7 @@ class Filter(object):
         #     if (0 <= start_index + offset < len(data_frame.index)):
         #         start_index = start_index + offset
         #
-        #         # data_frame = data_frame.ix[start_date < data_frame.index]
+        #         # data_frame = data_frame[start_date < data_frame.index]
         #
         # if(finish_date is not None):
         #     finish_index = data_frame.index.searchsorted(finish_date)
@@ -395,11 +403,15 @@ class Filter(object):
         # CAREFUL: need + 1 otherwise will only return 1 less than usual
         # return data_frame.iloc[start_date:finish_date]
 
-        # just use pandas, quicker and simpler code!
+        # Just use pandas, quicker and simpler code!
         if data_frame is None:
             return None
 
-        return data_frame.loc[start_date:finish_date]
+        # Slower method..
+        # return data_frame.loc[start_date:finish_date]
+
+        # Much faster, start and finish dates are inclusive
+        return data_frame[(data_frame.index >= start_date) & (data_frame.index <= finish_date)]
 
 
     def filter_time_series_by_time_of_day(self, hour, minute, data_frame, in_tz = None, out_tz = None):
@@ -660,7 +672,7 @@ class Filter(object):
 
         tickers_fields_list = []
 
-        # create ticker.field combination for series we wish to return
+        # Create ticker.field combination for series we wish to return
         for f in fields:
             for t in tickers:
                 tickers_fields_list.append(t + '.' + f)
@@ -672,7 +684,7 @@ class Filter(object):
 
     def resample_time_series_frequency(self, data_frame, data_resample_freq,
                                        data_resample_type = 'mean', fill_empties = False):
-        # should we take the mean, first, last in our resample
+        # Should we take the mean, first, last in our resample
         if data_resample_type == 'mean':
             data_frame_r = data_frame.resample(data_resample_freq).mean()
         elif data_resample_type == 'first':
@@ -698,7 +710,7 @@ class Filter(object):
         return data_frame
 
     def remove_out_FX_out_of_hours(self, data_frame):
-        """Filtered a time series for FX hours (ie. excludes 22h GMT Fri - 19h GMT Sun)
+        """Filtered a time series for FX hours (ie. excludes 22h GMT Fri - 19h GMT Sun and New Year's Day)
 
         Parameters
         ----------
@@ -715,9 +727,10 @@ class Filter(object):
         # remove Sun before 19:00 GMT
 
         # Monday = 0, ..., Sunday = 6
-        data_frame = data_frame.ix[~((data_frame.index.dayofweek == 4) & (data_frame.index.hour > 22))]
-        data_frame = data_frame.ix[~((data_frame.index.dayofweek == 5))]
-        data_frame = data_frame.ix[~((data_frame.index.dayofweek == 6)& (data_frame.index.hour < 19))]
+        data_frame = data_frame[~((data_frame.index.dayofweek == 4) & (data_frame.index.hour > 22))]
+        data_frame = data_frame[~((data_frame.index.dayofweek == 5))]
+        data_frame = data_frame[~((data_frame.index.dayofweek == 6)& (data_frame.index.hour < 19))]
+        data_frame = data_frame[~((data_frame.index.day == 1) & (data_frame.index.month == 1))]
 
         return data_frame
 
@@ -746,29 +759,29 @@ class Filter(object):
         DataFrame  (which the time zone is 'UTC')
         """
 
-        # change the time zone from 'UTC' to a given one
+        # Change the time zone from 'UTC' to a given one
         df.index = df.index.tz_convert(time_zone)
         df_mask = pandas.DataFrame(0,index=df.index,columns=['mask'])
 
-        # mask data with each given tuple
+        # Mask data with each given tuple
         for i in range(0, len(time_list)):
             start_hour = int(time_list[i][0].split(':')[0])
             start_minute = int(time_list[i][0].split(':')[1])
             end_hour = int(time_list[i][1].split(':')[0])
             end_minute = int(time_list[i][1].split(':')[1])
 
-            # e.g. if tuple is ('01:08', '03:02'),
+            # E.g. if tuple is ('01:08', '03:02'),
             # take hours in target - take values in [01:00,04:00]
             narray = np.where(df.index.hour.isin(range(start_hour,end_hour + 1)), 1, 0)
             df_mask_temp = pandas.DataFrame(index=df.index, columns=df_mask.columns.tolist(), data=narray)
 
-            # remove minutes not in target - remove values in [01:00,01:07], [03:03,03:59]
+            # Remove minutes not in target - remove values in [01:00,01:07], [03:03,03:59]
             narray = np.where(((df.index.hour == start_hour) & (df.index.minute < start_minute)), 0, 1)
             df_mask_temp = df_mask_temp * pandas.DataFrame(index=df.index, columns=df_mask.columns.tolist(), data=narray)
             narray = np.where((df.index.hour == end_hour) & (df.index.minute > end_minute), 0, 1)
             df_mask_temp = df_mask_temp * pandas.DataFrame(index=df.index, columns=df_mask.columns.tolist(), data=narray)
 
-            # collect all the periods we want to keep the data
+            # Collect all the periods we want to keep the data
             df_mask = df_mask + df_mask_temp
 
         narray = np.where(df_mask == 1, df, 0)
@@ -777,11 +790,6 @@ class Filter(object):
 
         return df
 
-
-
-
-
-
 #######################################################################################################################
 
 import datetime
@@ -889,6 +897,17 @@ if __name__ == '__main__':
 
     tsf = Filter()
 
+    if True:
+        import pandas as pd
+        dates = pd.date_range('01 Jan 2020', '10 Jan 2020', freq='D')
+        data_frame = pd.DataFrame(index=dates)
+
+        start_date = '03 Jan 2020'; finish_date = '06 Jan 2020'
+        print(data_frame.loc[start_date:finish_date])
+
+        # Much faster!
+        print(data_frame[(data_frame.index >= start_date) & (data_frame.index <= finish_date)])
+
     if False:
         start = pandas.to_datetime('2000-01-01')
         end = pandas.to_datetime('2020-01-01')
